@@ -118,8 +118,8 @@ class ExpressionParams(DefaultDependency):
         examples={
             "simple": {"description": "Simple band math.", "value": "b1/b2"},
             "multi-bands": {
-                "description": "Coma (,) delimited expressions (band1: b1/b2, band2: b2+b3).",
-                "value": "b1/b2,b2+b3",
+                "description": "Semicolon (;) delimited expressions (band1: b1/b2, band2: b2+b3).",
+                "value": "b1/b2;b2+b3",
             },
         },
     )
@@ -193,11 +193,11 @@ class AssetsBidxExprParams(DefaultDependency):
         examples={
             "one-asset": {
                 "description": "Return indexes 1,2,3 of asset `data`.",
-                "value": ["data|1,2,3"],
+                "value": ["data|1;2;3"],
             },
             "multi-assets": {
                 "description": "Return indexes 1,2,3 of asset `data` and indexes 1 of asset `cog`",
-                "value": ["data|1,2,3", "cog|1"],
+                "value": ["data|1;2;3", "cog|1"],
             },
         },
     )
@@ -237,6 +237,24 @@ class AssetsBidxExprParams(DefaultDependency):
             }
 
 
+@dataclass
+class AssetsBidxExprParamsOptional(AssetsBidxExprParams):
+    """Assets, Band Indexes and Expression parameters but with no requirement."""
+
+    def __post_init__(self):
+        """Post Init."""
+        if self.asset_indexes:
+            self.asset_indexes: Dict[str, Sequence[int]] = {  # type: ignore
+                idx.split("|")[0]: list(map(int, idx.split("|")[1].split(",")))
+                for idx in self.asset_indexes
+            }
+
+        if self.asset_expression:
+            self.asset_expression: Dict[str, str] = {  # type: ignore
+                idx.split("|")[0]: idx.split("|")[1] for idx in self.asset_expression
+            }
+
+
 @dataclass
 class AssetsBidxParams(AssetsParams):
     """asset and extra."""
@@ -249,11 +267,11 @@ class AssetsBidxParams(AssetsParams):
         examples={
             "one-asset": {
                 "description": "Return indexes 1,2,3 of asset `data`.",
-                "value": ["data|1,2,3"],
+                "value": ["data|1;2;3"],
             },
             "multi-assets": {
                 "description": "Return indexes 1,2,3 of asset `data` and indexes 1 of asset `cog`",
-                "value": ["data|1,2,3", "cog|1"],
+                "value": ["data|1;2;3", "cog|1"],
             },
         },
     )
